@@ -250,18 +250,18 @@ extern "C"
 #define HAVE_BLITWAIT 16
 
 /* other flags */
-#define HAVE_RWPAGE 1		/* vga_setreadpage() / vga_setwritepage() available */
-#define IS_INTERLACED 2		/* mode is interlaced */
-#define IS_MODEX 4		/* ModeX style 256 colors */
-#define IS_DYNAMICMODE 8	/* Dynamic defined mode */
-#define CAPABLE_LINEAR 16	/* Can go to linear addressing mode. */
-#define IS_LINEAR 32		/* Linear addressing can be used. */
-#define LINEAR_MODE 512		/* Linear mode is enabled */
-#define EXT_INFO_AVAILABLE 64	/* Returned modeinfo contains valid extended fields */
-#define RGB_MISORDERED 128	/* Mach32 32bpp uses 0BGR instead of BGR0. */
-    /* As of this version 1.25 also used to signal if real RGB
-       (red first in memory) is used instead of BGR (Mach32 DAC 4) */
-#define HAVE_EXT_SET 256	/* vga_ext_set() available */
+#define HAVE_RWPAGE 		   1	/* vga_setreadpage() / vga_setwritepage() available */
+#define IS_INTERLACED		   2	/* mode is interlaced */
+#define IS_MODEX			   4	/* ModeX style 256 colors */
+#define IS_DYNAMICMODE		   8	/* Dynamic defined mode */
+#define CAPABLE_LINEAR		  16	/* Can go to linear addressing mode. */
+#define IS_LINEAR			  32	/* Linear addressing can be used. */
+#define EXT_INFO_AVAILABLE	  64	/* Returned modeinfo contains valid extended fields */
+#define RGB_MISORDERED		 128	/* Mach32 32bpp uses 0BGR instead of BGR0. */
+#define HAVE_EXT_SET		 256	/* vga_ext_set() available */
+#define LINEAR_MODE			 512	/* Linear mode is enabled */
+#define IOCTL_SETDISPLAY	1024	/* The card supports ioctl method for setting display
+										start at next vertical blank time */
 
     typedef struct {
 	int width;
@@ -293,7 +293,9 @@ extern "C"
         int version;
         int size;
         int chipset;
-        int physmem;
+        long physmem;
+		long physmemsize;
+		void * linearmem;
     } vga_cardinfo;
 
     extern vga_cardinfo *vga_getcardinfo(void);
@@ -319,7 +321,8 @@ extern "C"
     extern void vga_disabledriverreport(void);
     extern int vga_setmodeX(void);
     extern int vga_init(void);	/* Used to return void in svgalib <= 1.12. */
-    extern int vga_initf(int);	
+    extern int vga_initf(int);
+	extern void vga_norevokeprivs(void);
     extern int vga_getmousetype(void);
     extern int vga_getmonitortype(void);
     extern void vga_setmousesupport(int s);
@@ -394,6 +397,7 @@ extern "C"
 
     extern void vga_setchipset(int c);
     extern void vga_setchipsetandfeatures(int c, int par1, int par2);
+    extern void vga_disablechipset(int c);
     extern void vga_gettextfont(void *font);
     extern void vga_puttextfont(void *font);
     extern void vga_settextmoderegs(void *regs);
@@ -534,6 +538,10 @@ extern "C"
 #define BLITS_SYNC			0
 #define BLITS_IN_BACKGROUND		0x1
 
+#ifdef ROP_XOR
+#undef ROP_XOR
+#endif
+
 /* Raster ops. */
 #define ROP_COPY			0	/* Straight copy. */
 #define ROP_OR				1	/* Source OR destination. */
@@ -575,6 +583,17 @@ extern void vga_runinbackground(int stat, ...);
 extern int vga_runinbackground_version(void);
 extern void vga_waitvtactive(void);
 
+#ifdef _SVGALIB_LRMI
+typedef struct {
+    int (*rm_init)(void);
+    int (*rm_call)(struct vm86_regs *r);
+    int (*rm_int)(int interrupt, struct vm86_regs *r);
+    void * (*rm_alloc_real)(int size);
+    void (*rm_free_real)(void *m);
+} LRMI_callbacks;
+extern int vga_set_LRMI_callbacks(LRMI_callbacks * LRMI);
+#endif
+
 #ifdef __cplusplus
 }
 
