@@ -55,6 +55,10 @@ static int irqs[MAX_NR_DEVICES];
 static devfs_handle_t devfs_handle;
 #endif
 
+#if defined(KERNEL_2_6) && !defined(CONFIG_DEVFS_FS)
+struct class_simple *svgalib_helper_class;
+#endif
+
 static int check_io_range(int port, int device) {
     return 1;
 }
@@ -127,14 +131,29 @@ static void task_startad(void *data) {
 }
 #endif
 
+#define GET_IOSTR \
+	get_user(iostr.port, &user_iostr->port); \
+	get_user(iostr.length, &user_iostr->length); \
+	get_user(iostr.string, &user_iostr->string); 
+#define GET_IOV \
+	get_user(iov.port, &user_iov->port); \
+	get_user(iov.val, &user_iov->val); 
+#define PUT_IOV \
+	put_user(iov.val, &user_iov->val); 
+#define GET_PCIV \
+	get_user(pciv.pcipos, &user_pciv->pcipos); \
+	get_user(pciv.address, &user_pciv->address); \
+	get_user(pciv.val, &user_pciv->val); 
+#define PUT_PCIV \
+	put_user(pciv.val, &user_pciv->val); 
 static int svgalib_helper_ioctl( struct inode *inode, struct file *filp, 
                           unsigned int cmd, unsigned long arg) {
 
-    io_t iov;
-    pcic_t pciv;
+    io_t iov, *user_iov=(io_t *)arg;
+    pcic_t pciv, *user_pciv=(pcic_t *)arg;
     int minor = my_minor(inode->i_rdev);
     struct pci_dev *pdev;
-    io_string_t iostr;
+    io_string_t iostr, *user_iostr=(io_string_t *)arg;
     int i=0, ret;
     u8 pb;
     u16 pw;
@@ -150,10 +169,10 @@ static int svgalib_helper_ioctl( struct inode *inode, struct file *filp,
     switch(_IOC_NR(cmd)) {
 
         case _IOC_NR(SVGAHELPER_REPOUTB):
-            copy_from_user(&iostr,(char *)arg,sizeof(iostr));
+			GET_IOSTR;
             if (iostr.length>4096) return -EINVAL;
 	    	if ( (outb_str = kmalloc(iostr.length, GFP_KERNEL )) == NULL ) return -ENOMEM;
-	    	copy_from_user(outb_str,iostr.string,iostr.length);
+	    	if(copy_from_user(outb_str,iostr.string,iostr.length)) return -EPERM;
 	    	if(check_io_range(iostr.port,minor)) {
 	        	for(i=0; i<iostr.length; i++) outb(outb_str[i], iostr.port);
 			} else ret = -EPERM;
@@ -161,120 +180,120 @@ static int svgalib_helper_ioctl( struct inode *inode, struct file *filp,
             break;
 
         case _IOC_NR(SVGAHELPER_OUTB):
-           copy_from_user(&iov,(char *)arg,sizeof(iov));
-           if(check_io_range(iov.port,minor))
-               outb(iov.val,iov.port);
-               else ret = -EPERM;
-        break;
+			GET_IOV;
+ 			if(check_io_range(iov.port,minor))
+ 				outb(iov.val,iov.port);
+				else ret = -EPERM;
+			break;
 
         case _IOC_NR(SVGAHELPER_OUTW):
-           copy_from_user(&iov,(char *)arg,sizeof(iov));
+			GET_IOV;
            if(check_io_range(iov.port,minor))
                outw(iov.val,iov.port);
                else ret = -EPERM;
         break;
 
         case _IOC_NR(SVGAHELPER_OUTL):
-           copy_from_user(&iov,(char *)arg,sizeof(iov));
+			GET_IOV;
            if(check_io_range(iov.port,minor))
                outl(iov.val,iov.port);
                else ret = -EPERM;
         break;
 
         case _IOC_NR(SVGAHELPER_INB):
-           copy_from_user(&iov,(char *)arg,sizeof(iov));
+			GET_IOV;
            if(check_io_range(iov.port,minor))
                iov.val=inb(iov.port);
                else ret = -EPERM;
-           copy_to_user((char *)arg,&iov,sizeof(iov));
+		   PUT_IOV;
         break;
 
         case _IOC_NR(SVGAHELPER_INW):
-           copy_from_user(&iov,(char *)arg,sizeof(iov));
+			GET_IOV;
            if(check_io_range(iov.port,minor))
                iov.val=inw(iov.port);
                else ret = -EPERM;
-           copy_to_user((char *)arg,&iov,sizeof(iov));
+		   PUT_IOV;
         break;
 
         case _IOC_NR(SVGAHELPER_INL):
-           copy_from_user(&iov,(char *)arg,sizeof(iov));
+			GET_IOV;
            if(check_io_range(iov.port,minor))
                iov.val=inl(iov.port);
                else ret = -EPERM;
-           copy_to_user((char *)arg,&iov,sizeof(iov));
+		   PUT_IOV;
         break;
 
         case _IOC_NR(SVGAHELPER_WRITEB):
-           copy_from_user(&iov,(char *)arg,sizeof(iov));
-           writeb(iov.val,iov.port);
+			GET_IOV;
+           writeb(iov.val,(u8 *)iov.port);
         break;
 
         case _IOC_NR(SVGAHELPER_WRITEW):
-           copy_from_user(&iov,(char *)arg,sizeof(iov));
-           writew(iov.val,iov.port);
+			GET_IOV;
+           writew(iov.val,(u16 *)iov.port);
         break;
 
         case _IOC_NR(SVGAHELPER_WRITEL):
-           copy_from_user(&iov,(char *)arg,sizeof(iov));
-           writel(iov.val,iov.port);
+			GET_IOV;
+           writel(iov.val,(u32 *)iov.port);
         break;
 
         case _IOC_NR(SVGAHELPER_READB):
-           copy_from_user(&iov,(char *)arg,sizeof(iov));
-           iov.val=readb(iov.port);
-           copy_to_user((char *)arg,&iov,sizeof(iov));
+			GET_IOV;
+           iov.val=readb((u8 *)iov.port);
+		   PUT_IOV;
         break;
 
         case _IOC_NR(SVGAHELPER_READW):
-           copy_from_user(&iov,(char *)arg,sizeof(iov));
-           iov.val=readw(iov.port);
-           copy_to_user((char *)arg,&iov,sizeof(iov));
+			GET_IOV;
+           iov.val=readw((u16 *)iov.port);
+		   PUT_IOV;
         break;
 
         case _IOC_NR(SVGAHELPER_READL):
-           copy_from_user(&iov,(char *)arg,sizeof(iov));
-           iov.val=readl(iov.port);
-           copy_to_user((char *)arg,&iov,sizeof(iov));
+			GET_IOV;
+           iov.val=readl((u32 *)iov.port);
+		   PUT_IOV;
         break;
 
         case _IOC_NR(SVGAHELPER_PCIINB):
-            copy_from_user(&pciv,(char *)arg,sizeof(pciv));
+			GET_PCIV;
             pdev = get_pci_dev(pciv.pcipos, minor);
             if(!pdev) return -EINVAL;
             pci_read_config_byte(pdev, pciv.address, &pb);
             pciv.val=pb;
-            copy_to_user((char *)arg,&pciv,sizeof(pciv));
+			PUT_PCIV;
             break;
 
         case _IOC_NR(SVGAHELPER_PCIINW):
-            copy_from_user(&pciv,(char *)arg,sizeof(pciv));
+			GET_PCIV;
             pdev = get_pci_dev(pciv.pcipos, minor);
             if(!pdev) return -EINVAL;
             pci_read_config_word(pdev, pciv.address, &pw);
             pciv.val=pw;
-            copy_to_user((char *)arg,&pciv,sizeof(pciv));
+			PUT_PCIV;
             break;
 
         case _IOC_NR(SVGAHELPER_PCIINL):
-            copy_from_user(&pciv,(char *)arg,sizeof(pciv));
+			GET_PCIV;
             pdev = get_pci_dev(pciv.pcipos, minor);
             if(!pdev) return -EINVAL;
             pci_read_config_dword(pdev, pciv.address, &pl);
             pciv.val=pl;
-            copy_to_user((char *)arg,&pciv,sizeof(pciv));
+			PUT_PCIV;
             break;
 
         case _IOC_NR(SVGAHELPER_PCIAPLEN):
-            copy_from_user(&pciv,(char *)arg,sizeof(pciv));
+			GET_PCIV;
             i = get_dev(pciv.pcipos, minor);
             if((i==0) | (pciv.address>5)) return -EINVAL;
             pciv.val=sh_pci_devs[i]->len[pciv.address];
-            copy_to_user((char *)arg,&pciv,sizeof(pciv));
+			PUT_PCIV;
             break;
 
         case _IOC_NR(SVGAHELPER_PCIOUTB):
-            copy_from_user(&pciv,(char *)arg,sizeof(pciv));
+			GET_PCIV;
             pdev = get_pci_dev(pciv.pcipos, minor);
             if(!pdev) return -EINVAL;
             pb=pciv.val;
@@ -282,7 +301,7 @@ static int svgalib_helper_ioctl( struct inode *inode, struct file *filp,
             break;
 
         case _IOC_NR(SVGAHELPER_PCIOUTW):
-            copy_from_user(&pciv,(char *)arg,sizeof(pciv));
+			GET_PCIV;
             pdev = get_pci_dev(pciv.pcipos, minor);
             if(!pdev) return -EINVAL;
             pw=pciv.val;
@@ -290,7 +309,7 @@ static int svgalib_helper_ioctl( struct inode *inode, struct file *filp,
             break;
 
         case _IOC_NR(SVGAHELPER_PCIOUTL):
-            copy_from_user(&pciv,(char *)arg,sizeof(pciv));
+			GET_PCIV;
             pdev = get_pci_dev(pciv.pcipos, minor);
             if(!pdev) return -EINVAL;
             pl=pciv.val;
@@ -319,7 +338,8 @@ static int svgalib_helper_ioctl( struct inode *inode, struct file *filp,
                 if(i==0 || i==-1 || i==255) return -EINVAL;
 				sh_pci_devs[minor]->vsync=1;
                 sh_pci_devs[minor]->enable_vsync(sh_pci_devs[minor]);
-	            interruptible_sleep_on(&sh_pci_devs[minor]->vsync_wait);
+	            wait_event_interruptible(sh_pci_devs[minor]->vsync_wait, 
+						!sh_pci_devs[minor]->vsync);
                 if(sh_pci_devs[minor]->vsync) sh_pci_devs[minor]->ack_vsync(sh_pci_devs[minor]);
             	if(sh_pci_devs[minor]->vsync) return -ERESTARTSYS;
             } else {
@@ -329,7 +349,7 @@ static int svgalib_helper_ioctl( struct inode *inode, struct file *filp,
                 while(irqs[i]!=-1)
                     request_irq(irqs[i++], vsync_interrupt, SA_SHIRQ, "svgalib_helper", sdev_id);
                 vga_enable_vsync((void *)sdev_id);
-				interruptible_sleep_on(&vsync_wait);
+				wait_event_interruptible(vsync_wait, !vsync);
                 i=0;
                 if(vsync) vga_ack_vsync((void *)sdev_id);
                 while(irqs[i]!=-1)
@@ -450,8 +470,6 @@ int remap_cache(struct vm_area_struct *vma, unsigned long off) {
 	pgprot_val(vma->vm_page_prot) |= _PAGE_NO_CACHE; 
 #elif defined(__ia64__)
 	vma->vm_page_prot = pgprot_writecombine(vma->vm_page_prot);
-#elif defined(__hppa__)
-	pgprot_val(vma->vm_page_prot) |= _PAGE_NO_CACHE; 
 #else
 #warning What do we have to do here??
 #endif
@@ -470,8 +488,11 @@ int check_mem(int card, unsigned long start, unsigned long len) {
     int type;
 #endif
         
+	if (start+len < start || len >= 0x40000000) return -3;
+	
     rstart=start;
     rlen=len;
+
 #ifdef __alpha__
     type = start>>32;
     switch(type) {
@@ -537,6 +558,7 @@ int init_module(void)
 {
     int result, i, j;
     struct pci_dev *dev=NULL;
+	char name[255];
 #ifdef CONFIG_DEVFS_FS
 # ifndef KERNEL_2_6
     devfs_handle_t slave_handle;
@@ -581,10 +603,13 @@ int init_module(void)
 # endif
 #endif /* devfsd support */
 
+	SLH_SYSFS_REGISTER;
+	SLH_SYSFS_ADD_CONTROL;
+
     if(pci_present()) {
         while((dev= all_devices ? 
-					pci_find_device(PCI_ANY_ID, PCI_ANY_ID, dev) :
-					pci_find_class(PCI_CLASS_DISPLAY_VGA<<8,dev)) && 
+					PCI_GET_DEVICE(PCI_ANY_ID, PCI_ANY_ID, dev) :
+					PCI_GET_CLASS(PCI_CLASS_DISPLAY_VGA<<8,dev)) && 
               (num_devices<=MAX_NR_DEVICES)) {
             if((sh_pci_devs[num_devices]=kmalloc(sizeof(struct sh_pci_device),GFP_KERNEL))==NULL) {
                 goto nomem_error;
@@ -625,6 +650,10 @@ int init_module(void)
 			sh_pci_devs[num_devices]->startad=-1;
 #endif
 			sh_pci_devs[num_devices]->opencount=0;
+
+			sprintf(name, "svga%d", num_devices);
+			SLH_SYSFS_ADD_DEVICE(name, num_devices);
+			
             num_devices++;
         }
     }
@@ -653,7 +682,13 @@ int init_module(void)
 
 nomem_error:
     for(i=0;i<MAX_NR_DEVICES;i++) 
-        if(sh_pci_devs[i])kfree(sh_pci_devs[i]);
+        if(sh_pci_devs[i]) {
+			SLH_SYSFS_REMOVE_DEVICE(i);
+			kfree(sh_pci_devs[i]);
+		}
+
+	SLH_SYSFS_REMOVE_DEVICE(0);
+	SLH_SYSFS_UNREGISTER;
 
 	devfs_unregister_chrdev(SVGALIB_HELPER_MAJOR, "svgalib_helper");
 		
@@ -665,8 +700,12 @@ void cleanup_module(void)
     int i;
     for(i=0;i<MAX_NR_DEVICES;i++) 
         if(sh_pci_devs[i]) {
+			SLH_SYSFS_REMOVE_DEVICE(i);
             kfree(sh_pci_devs[i]);
         }
+	
+	SLH_SYSFS_REMOVE_DEVICE(0);
+	SLH_SYSFS_UNREGISTER;
      
 #ifdef CONFIG_DEVFS_FS
 # ifndef KERNEL_2_6
