@@ -1,4 +1,4 @@
-#define DEBUG 1
+#define DEBUG 0
 /*
 Linux Real Mode Interface - A library of DPMI-like functions for Linux.
 
@@ -518,7 +518,7 @@ em_inb(void)
 	asm volatile ("inb (%w1), %b0"
 	 : "=a" (context.vm.regs.eax)
 	 : "d" (context.vm.regs.edx), "0" (context.vm.regs.eax));
-#ifdef DEBUG
+#if DEBUG
 printf("inb  %04x       %02x\n",context.vm.regs.edx,context.vm.regs.eax);
 #endif
 	}
@@ -529,7 +529,7 @@ em_inw(void)
 	asm volatile ("inw (%w1), %w0"
 	 : "=a" (context.vm.regs.eax)
 	 : "d" (context.vm.regs.edx), "0" (context.vm.regs.eax));
-#ifdef DEBUG
+#if DEBUG
 printf("inw  %04x     %04x\n",context.vm.regs.edx,context.vm.regs.eax);
 #endif
 	}
@@ -540,7 +540,7 @@ em_inl(void)
 	asm volatile ("inl (%w1), %0"
 	 : "=a" (context.vm.regs.eax)
 	 : "d" (context.vm.regs.edx));
-#ifdef DEBUG
+#if DEBUG
 printf("inl  %04x %08x\n",context.vm.regs.edx,context.vm.regs.eax);
 #endif
 	}
@@ -551,7 +551,7 @@ em_outb(void)
 	asm volatile ("outb %b0, (%w1)"
 	 : : "a" (context.vm.regs.eax),
 	 "d" (context.vm.regs.edx));
-#ifdef DEBUG
+#if DEBUG
 printf("outb %04x       %02x\n",context.vm.regs.edx,context.vm.regs.eax);
 #endif
 	}
@@ -562,7 +562,7 @@ em_outw(void)
 	asm volatile ("outw %w0, (%w1)"
 	 : : "a" (context.vm.regs.eax),
 	 "d" (context.vm.regs.edx));
-#ifdef DEBUG
+#if DEBUG
 printf("outw %04x     %02x\n",context.vm.regs.edx,context.vm.regs.eax);
 #endif
 	}
@@ -573,7 +573,7 @@ em_outl(void)
 	asm volatile ("outl %0, (%w1)"
 	 : : "a" (context.vm.regs.eax),
 	 "d" (context.vm.regs.edx));
-#ifdef DEBUG
+#if DEBUG
 printf("outl %04x %08x\n",context.vm.regs.edx,context.vm.regs.eax);
 #endif
 	}
