@@ -52,8 +52,8 @@
 #define MIN(a,b)	(((a)<(b))?(a):(b))
 #define ABS(a)		(((a)<0)?(-(a)):(a))
 
-#define ATIGETEXT(index)	(outb(ati_base, (index)), port_in(1 + ati_base))
-#define ATISETEXT(index, value)	outw(ati_base, ((value) << 8 | (index)))
+#define ATIGETEXT(index)	(port_out_r(ati_base, (index)), port_in(1 + ati_base))
+#define ATISETEXT(index, value)	port_outw_r(ati_base, ((value) << 8 | (index)))
 
 static unsigned char ati_flags_42, ati_flags_44;
 static int ati_chiptype;
