@@ -182,8 +182,8 @@ enum {
 
 int __svgalib_cirrus_inlinearmode(void)
 {
-    outb(SEQ_I, 0x07);
-    return (inb(SEQ_D) & 0xf0) != 0;
+    port_out_r(SEQ_I, 0x07);
+    return (port_in(SEQ_D) & 0xf0) != 0;
 }
 
 /* Fill in chipset specific mode information */
@@ -285,27 +285,27 @@ static int cirrus_saveregs(unsigned char regs[])
     /* Save Hicolor DAC register. */
     /* My 5446 works without this. With this 8 bpp and text modes do not work. - MZ */
     if (CHIP_HAS_HIDDENDAC() && CHECKCHIPNOTEQUAL(CLGD5436)) {
-	outb(0x3c6, 0);
-	outb(0x3c6, 0xff);
-	inb(0x3c6);
-	inb(0x3c6);
-	inb(0x3c6);
-	inb(0x3c6);
-	regs[CIRRUSREG_DAC] = inb(0x3c6);
+	port_out_r(0x3c6, 0);
+	port_out_r(0x3c6, 0xff);
+	port_in(0x3c6);
+	port_in(0x3c6);
+	port_in(0x3c6);
+	port_in(0x3c6);
+	regs[CIRRUSREG_DAC] = port_in(0x3c6);
     }
     return CIRRUS_TOTAL_REGS - VGA_TOTAL_REGS;
 }
 
 static void writehicolordac(unsigned char c)
 {
-    outb(0x3c6, 0);
-    outb(0x3c6, 0xff);
-    inb(0x3c6);
-    inb(0x3c6);
-    inb(0x3c6);
-    inb(0x3c6);
-    outb(0x3c6, c);
-    inb(0x3c8);
+    port_out_r(0x3c6, 0);
+    port_out_r(0x3c6, 0xff);
+    port_in(0x3c6);
+    port_in(0x3c6);
+    port_in(0x3c6);
+    port_in(0x3c6);
+    port_out_r(0x3c6, c);
+    port_in(0x3c8);
 }
 
 
@@ -605,7 +605,7 @@ static int cirrus_setmode(int mode, int prv_mode)
 	/* Let the standard VGA driver set standard VGA modes */
 	/* But first reset an Cirrus extended register that */
 	/* an old XFree86 Trident probe corrupts. */
-	outw(CRT_IC, 0x4a0b);
+	port_outw_r(CRT_IC, 0x4a0b);
 	return __svgalib_vga_driverspecs.setmode(mode, prv_mode);
     }
     if (!cirrus_modeavailable(mode))
@@ -650,22 +650,22 @@ static void cirrus_unlock(void)
     int vgaIOBase, temp;
 
     /* Are we Mono or Color? */
-    vgaIOBase = (inb(0x3CC) & 0x01) ? 0x3D0 : 0x3B0;
+    vgaIOBase = (port_in(0x3CC) & 0x01) ? 0x3D0 : 0x3B0;
 
-    outb(SEQ_I, 0x06);
-    outb(SEQ_D, 0x12);		/* unlock cirrus special */
+    port_out_r(SEQ_I, 0x06);
+    port_out_r(SEQ_D, 0x12);		/* unlock cirrus special */
 
     /* Put the Vert. Retrace End Reg in temp */
 
-    outb(vgaIOBase + 4, 0x11);
-    temp = inb(vgaIOBase + 5);
+    port_out_r(vgaIOBase + 4, 0x11);
+    temp = port_in(vgaIOBase + 5);
 
     /* Put it back with PR bit set to 0 */
     /* This unprotects the 0-7 CRTC regs so */
     /* they can be modified, i.e. we can set */
     /* the timing. */
 
-    outb(vgaIOBase + 5, temp & 0x7F);
+    port_out_r(vgaIOBase + 5, temp & 0x7F);
 }
 
 
@@ -674,8 +674,8 @@ static void cirrus_unlock(void)
 
 static void cirrus_lock(void)
 {
-    outb(SEQ_I, 0x06);
-    outb(SEQ_D, 0x0F);		/* relock cirrus special */
+    port_out_r(SEQ_I, 0x06);
+    port_out_r(SEQ_D, 0x0F);		/* relock cirrus special */
 }
 
 
@@ -686,27 +686,27 @@ static int cirrus_test(void)
     int oldlockreg;
     int lockreg;
 
-    outb(SEQ_I, 0x06);
-    oldlockreg = inb(SEQ_D);
+    port_out_r(SEQ_I, 0x06);
+    oldlockreg = port_in(SEQ_D);
 
     cirrus_unlock();
 
     /* If it's a Cirrus at all, we should be */
     /* able to read back the lock register */
 
-    outb(SEQ_I, 0x06);
-    lockreg = inb(SEQ_D);
+    port_out_r(SEQ_I, 0x06);
+    lockreg = port_in(SEQ_D);
 
     /* Ok, if it's not 0x12, we're not a Cirrus542X. */
     if (lockreg != 0x12) {
-	outb(SEQ_I, 0x06);
-	outb(SEQ_D, oldlockreg);
+	port_out_r(SEQ_I, 0x06);
+	port_out_r(SEQ_D, oldlockreg);
 	return 0;
     }
     /* The above check seems to be weak, so we also check the chip ID. */
 
-    outb(__svgalib_CRT_I, 0x27);
-    switch (inb(__svgalib_CRT_D) >> 2) {
+    port_out_r(__svgalib_CRT_I, 0x27);
+    switch (port_in(__svgalib_CRT_D) >> 2) {
     case 0x22:
     case 0x23:
     case 0x24:
@@ -720,8 +720,8 @@ static int cirrus_test(void)
     case 0x0E:			/* 7548 */
 	break;
     default:
-	outb(SEQ_I, 0x06);
-	outb(SEQ_D, oldlockreg);
+	port_out_r(SEQ_I, 0x06);
+	port_out_r(SEQ_D, oldlockreg);
 	return 0;
     }
 
@@ -736,13 +736,13 @@ static int cirrus_test(void)
 static void cirrus_setpage_2M(int page)
 {
     /* Cirrus banking register has been set to 16K granularity */
-    outw(GRA_I, (page << 10) + 0x09);
+    port_outw_r(GRA_I, (page << 10) + 0x09);
 }
 
 static void cirrus_setpage(int page)
 {
     /* default 4K granularity */
-    outw(GRA_I, (page << 12) + 0x09);
+    port_outw_r(GRA_I, (page << 12) + 0x09);
 }
 
 
@@ -760,21 +760,21 @@ static void cirrus_setwrpage(int page)
 
 static void cirrus_setdisplaystart(int address)
 {
-    outw(CRT_IC, 0x0d + ((address >> 2) & 0x00ff) * 256);	/* sa2-sa9 */
-    outw(CRT_IC, 0x0c + ((address >> 2) & 0xff00));	/* sa10-sa17 */
-    inb(0x3da);			/* set ATC to addressing mode */
-    outb(ATT_IW, 0x13 + 0x20);	/* select ATC reg 0x13 */
+    port_outw_r(CRT_IC, 0x0d + ((address >> 2) & 0x00ff) * 256);	/* sa2-sa9 */
+    port_outw_r(CRT_IC, 0x0c + ((address >> 2) & 0xff00));	/* sa10-sa17 */
+    port_in(0x3da);			/* set ATC to addressing mode */
+    port_out_r(ATT_IW, 0x13 + 0x20);	/* select ATC reg 0x13 */
     /* Cirrus specific bits 0,1 and 18,19,20: */
-    outb(ATT_IW, (inb(ATT_R) & 0xf0) | (address & 3));
+    port_out_r(ATT_IW, (port_in(ATT_R) & 0xf0) | (address & 3));
     /* write sa0-1 to bits 0-1; other cards use bits 1-2 */
-    outb(CRT_IC, 0x1b);
-    outb(CRT_DC, (inb(CRT_DC) & 0xf2)
+    port_out_r(CRT_IC, 0x1b);
+    port_out_r(CRT_DC, (port_in(CRT_DC) & 0xf2)
 	 | ((address & 0x40000) >> 18)	/* sa18: write to bit 0 */
 	 |((address & 0x80000) >> 17)	/* sa19: write to bit 2 */
 	 |((address & 0x100000) >> 17));	/* sa20: write to bit 3 */
-    outb(CRT_IC, 0x1d);
+    port_out_r(CRT_IC, 0x1d);
     if (cirrus_memory > 2048)
-	outb(CRT_DC, (inb(CRT_DC) & 0x7f)
+	port_out_r(CRT_DC, (port_in(CRT_DC) & 0x7f)
 	     | ((address & 0x200000) >> 14));	/* sa21: write to bit 7 */
 }
 
@@ -784,18 +784,18 @@ static void cirrus_setdisplaystart(int address)
 
 static void cirrus_setlogicalwidth(int width)
 {
-    outw(CRT_IC, 0x13 + (width >> 3) * 256);	/* lw3-lw11 */
-    outb(CRT_IC, 0x1b);
-    outb(CRT_DC, (inb(CRT_DC) & 0xef) | ((width & 0x800) >> 7));
+    port_outw_r(CRT_IC, 0x13 + (width >> 3) * 256);	/* lw3-lw11 */
+    port_out_r(CRT_IC, 0x1b);
+    port_out_r(CRT_DC, (port_in(CRT_DC) & 0xef) | ((width & 0x800) >> 7));
     /* write lw12 to bit 4 of Sequencer reg. 0x1b */
 }
 
 static void cirrus_setlinear(int addr)
 {
     int val;
-    outb(SEQ_I, 0x07);
-    val = inb(SEQ_D);
-    outb(SEQ_D, (val & 0x0f) | (addr << 4));
+    port_out_r(SEQ_I, 0x07);
+    val = port_in(SEQ_D);
+    port_out_r(SEQ_D, (val & 0x0f) | (addr << 4));
 }
 
 static int cirrus_linear(int op, int param)
@@ -925,8 +925,8 @@ static int cirrus_init(int force, int par1, int par2)
 	cirrus_chiptype = par2;
     } else {
 	unsigned char partstatus;
-	outb(__svgalib_CRT_I, 0x27);
-	cirrus_chiptype = inb(__svgalib_CRT_D) >> 2;
+	port_out_r(__svgalib_CRT_I, 0x27);
+	cirrus_chiptype = port_in(__svgalib_CRT_D) >> 2;
 	cirrus_chiprev = 0;
 	partstatus = __svgalib_inCR(0x25);
 	switch (cirrus_chiptype) {
@@ -935,13 +935,13 @@ static int cirrus_init(int force, int par1, int par2)
 #if 0
 	    /* Check for CL-GD5420-75QC-B. */
 	    /* It has a Hidden-DAC register. */
-	    outb(0x3C6, 0x00);
-	    outb(0x3C6, 0xFF);
-	    inb(0x3C6);
-	    inb(0x3c6);
-	    inb(0x3C6);
-	    inb(0x3C6);
-	    if (inb(0x3C6) != 0xFF)
+	    port_out_r(0x3C6, 0x00);
+	    port_out_r(0x3C6, 0xFF);
+	    port_in(0x3C6);
+	    port_in(0x3c6);
+	    port_in(0x3C6);
+	    port_in(0x3C6);
+	    if (port_in(0x3C6) != 0xFF)
 		cirrus_chiptype = CLGD5420B;
 #endif
 	    break;
@@ -1005,9 +1005,9 @@ static int cirrus_init(int force, int par1, int par2)
 #endif
 
 	/* Now determine the amount of memory. */
-	outb(SEQ_I, 0x0a);	/* read memory register */
+	port_out_r(SEQ_I, 0x0a);	/* read memory register */
 	/* This depends on the BIOS having set a scratch register. */
-	v = inb(SEQ_D);
+	v = port_in(SEQ_D);
 	cirrus_memory = 256 << ((v >> 3) & 3);
 
 	/* Determine memory the correct way for the 543x, and
@@ -1016,8 +1016,8 @@ static int cirrus_init(int force, int par1, int par2)
 				       && cirrus_chiptype != CLGD5420)) {
 	    unsigned char SRF;
 	    cirrus_memory = 512;
-	    outb(SEQ_I, 0x0f);
-	    SRF = inb(SEQ_D);
+	    port_out_r(SEQ_I, 0x0f);
+	    SRF = port_in(SEQ_D);
 	    if (SRF & 0x10)
 		/* 32-bit DRAM bus. */
 		cirrus_memory *= 2;
@@ -1306,94 +1306,94 @@ static int cirrus_init(int force, int par1, int par2)
 /* Macros for normal I/O BitBLT register access. */
 
 #define SETSRCADDR(addr) \
-	outw(GRA_I, (((addr) & 0x000000FF) << 8) | 0x2C); \
-	outw(GRA_I, (((addr) & 0x0000FF00)) | 0x2D); \
-	outw(GRA_I, (((addr) & 0x003F0000) >> 8) | 0x2E);
+	port_outw_r(GRA_I, (((addr) & 0x000000FF) << 8) | 0x2C); \
+	port_outw_r(GRA_I, (((addr) & 0x0000FF00)) | 0x2D); \
+	port_outw_r(GRA_I, (((addr) & 0x003F0000) >> 8) | 0x2E);
 
 #define SETDESTADDR(addr) \
-	outw(GRA_I, (((addr) & 0x000000FF) << 8) | 0x28); \
-	outw(GRA_I, (((addr) & 0x0000FF00)) | 0x29); \
-	outw(GRA_I, (((addr) & 0x003F0000) >> 8) | 0x2A);
+	port_outw_r(GRA_I, (((addr) & 0x000000FF) << 8) | 0x28); \
+	port_outw_r(GRA_I, (((addr) & 0x0000FF00)) | 0x29); \
+	port_outw_r(GRA_I, (((addr) & 0x003F0000) >> 8) | 0x2A);
 
 /* Pitch: the 5426 goes up to 4095, the 5434 can do 8191. */
 
 #define SETDESTPITCH(pitch) \
-	outw(GRA_I, (((pitch) & 0x000000FF) << 8) | 0x24); \
-	outw(GRA_I, (((pitch) & 0x00001F00)) | 0x25);
+	port_outw_r(GRA_I, (((pitch) & 0x000000FF) << 8) | 0x24); \
+	port_outw_r(GRA_I, (((pitch) & 0x00001F00)) | 0x25);
 
 #define SETSRCPITCH(pitch) \
-	outw(GRA_I, (((pitch) & 0x000000FF) << 8) | 0x26); \
-	outw(GRA_I, (((pitch) & 0x00001F00)) | 0x27);
+	port_outw_r(GRA_I, (((pitch) & 0x000000FF) << 8) | 0x26); \
+	port_outw_r(GRA_I, (((pitch) & 0x00001F00)) | 0x27);
 
 /* Width: the 5426 goes up to 2048, the 5434 can do 8192. */
 
 #define SETWIDTH(width) \
-	outw(GRA_I, ((((width) - 1) & 0x000000FF) << 8) | 0x20); \
-	outw(GRA_I, ((((width) - 1) & 0x00001F00)) | 0x21);
+	port_outw_r(GRA_I, ((((width) - 1) & 0x000000FF) << 8) | 0x20); \
+	port_outw_r(GRA_I, ((((width) - 1) & 0x00001F00)) | 0x21);
 
 /* Height: the 5426 goes up to 1024, the 5434 can do 2048. */
 /* It appears many 5434's only go up to 1024. */
 
 #define SETHEIGHT(height) \
-	outw(GRA_I, ((((height) - 1) & 0x000000FF) << 8) | 0x22); \
-	outw(GRA_I, (((height) - 1) & 0x00000700) | 0x23);
+	port_outw_r(GRA_I, ((((height) - 1) & 0x000000FF) << 8) | 0x22); \
+	port_outw_r(GRA_I, (((height) - 1) & 0x00000700) | 0x23);
 
 #define SETBLTMODE(m) \
-	outw(GRA_I, ((m) << 8) | 0x30);
+	port_outw_r(GRA_I, ((m) << 8) | 0x30);
 
 #define SETBLTWRITEMASK(m) \
-	outw(GRA_I, ((m) << 8) | 0x2F);
+	port_outw_r(GRA_I, ((m) << 8) | 0x2F);
 
 #define SETTRANSPARENCYCOLOR(c) \
-	outw(GRA_I, ((c) << 8) | 0x34);
+	port_outw_r(GRA_I, ((c) << 8) | 0x34);
 
 #define SETTRANSPARENCYCOLOR16(c) \
-	outw(GRA_I, ((c) << 8) | 0x34); \
-	outw(GRA_I, (c & 0xFF00) | 0x35);
+	port_outw_r(GRA_I, ((c) << 8) | 0x34); \
+	port_outw_r(GRA_I, (c & 0xFF00) | 0x35);
 
 #define SETTRANSPARENCYCOLORMASK16(m) \
-	outw(GRA_I, ((m) << 8) | 0x38); \
-	outw(GRA_I, ((m) & 0xFF00) | 0x39);
+	port_outw_r(GRA_I, ((m) << 8) | 0x38); \
+	port_outw_r(GRA_I, ((m) & 0xFF00) | 0x39);
 
 #define SETROP(rop) \
-	outw(GRA_I, ((rop) << 8) | 0x32);
+	port_outw_r(GRA_I, ((rop) << 8) | 0x32);
 
 #define SETFOREGROUNDCOLOR(c) \
-	outw(GRA_I, 0x01 + ((c) << 8));
+	port_outw_r(GRA_I, 0x01 + ((c) << 8));
 
 #define SETBACKGROUNDCOLOR(c) \
-	outw(GRA_I, 0x00 + ((c) << 8));
+	port_outw_r(GRA_I, 0x00 + ((c) << 8));
 
 #define SETFOREGROUNDCOLOR16(c) \
-	outw(GRA_I, 0x01 + ((c) << 8)); \
-	outw(GRA_I, 0x11 + ((c) & 0xFF00));
+	port_outw_r(GRA_I, 0x01 + ((c) << 8)); \
+	port_outw_r(GRA_I, 0x11 + ((c) & 0xFF00));
 
 #define SETBACKGROUNDCOLOR16(c) \
-	outw(GRA_I, 0x00 + ((c) << 8)); \
-	outw(GRA_I, 0x10 + ((c) & 0xFF00)); \
+	port_outw_r(GRA_I, 0x00 + ((c) << 8)); \
+	port_outw_r(GRA_I, 0x10 + ((c) & 0xFF00)); \
 
 #define SETFOREGROUNDCOLOR32(c) \
-	outw(GRA_I, 0x01 + ((c) << 8)); \
-	outw(GRA_I, 0x11 + ((c) & 0xFF00)); \
-	outw(GRA_I, 0x13 + (((c) & 0xFf0000) >> 8)); \
-	outw(GRA_I, 0x15 + (((unsigned int)(c) & 0xFF000000) >> 16));
+	port_outw_r(GRA_I, 0x01 + ((c) << 8)); \
+	port_outw_r(GRA_I, 0x11 + ((c) & 0xFF00)); \
+	port_outw_r(GRA_I, 0x13 + (((c) & 0xFf0000) >> 8)); \
+	port_outw_r(GRA_I, 0x15 + (((unsigned int)(c) & 0xFF000000) >> 16));
 
 #define SETBACKGROUNDCOLOR32(c) \
-	outw(GRA_I, 0x00 + ((c) << 8)); \
-	outw(GRA_I, 0x10 + ((c) & 0xFF00)); \
-	outw(GRA_I, 0x12 + (((c) & 0xFF0000) >> 8)); \
-	outw(GRA_I, 0x14 + (((unsigned int)(c) & 0xFF000000) >> 16));
+	port_outw_r(GRA_I, 0x00 + ((c) << 8)); \
+	port_outw_r(GRA_I, 0x10 + ((c) & 0xFF00)); \
+	port_outw_r(GRA_I, 0x12 + (((c) & 0xFF0000) >> 8)); \
+	port_outw_r(GRA_I, 0x14 + (((unsigned int)(c) & 0xFF000000) >> 16));
 
 #define STARTBLT() { \
 	unsigned char tmp; \
-	outb(GRA_I, 0x31); \
-	tmp = inb(GRA_D); \
-	outb(GRA_D, tmp | 0x02); \
+	port_out_r(GRA_I, 0x31); \
+	tmp = port_in(GRA_D); \
+	port_out_r(GRA_D, tmp | 0x02); \
 	}
 
 #define BLTBUSY(s) { \
-	outb(GRA_I, 0x31); \
-	s = inb(GRA_D) & 1; \
+	port_out_r(GRA_I, 0x31); \
+	s = port_in(GRA_D) & 1; \
 	}
 
 #define WAITUNTILFINISHED() \
