@@ -198,7 +198,7 @@ inrestore=0;
 
 static int g400_modeavailable(int mode)
 {
-    struct info *info;
+    struct vgainfo *info;
     ModeTiming *modetiming;
     ModeInfo *modeinfo;
 
