@@ -691,23 +691,23 @@ static int init(int force, int par1, int par2)
     __svgalib_mm_io_mapio();
     
     if (force) {
-	memory = par1;
+		memory = par1;
     } else {
         memory = 512;
     };
 
 #ifdef USE_GTT
-    if(*(unsigned int *)(__svgalib_vgammbase + 0x2020) & 1) {
+    if(v_readl(0x2020) & 1) {
        /* GTT already set */
        memory = 4096;
     } else {
         memory = 4096;
         ioctl(__svgalib_mem_fd, SVGAHELPER_I810GTT, &t);
-        *(unsigned int *)(__svgalib_vgammbase + 0x2020) = t | 1;
+        v_writel(t|1, 0x2020);
         for(i=0;i<1024;i++) {
             t=i;
             ioctl(__svgalib_mem_fd, SVGAHELPER_I810GTTE, &t);
-            *(unsigned int *)(__svgalib_vgammbase + 0x10000 + 4*i) = t;
+            v_writel(t, 0x10000 + 4*i);
         }
     }
     cur_base = (memory>>2)-1;
@@ -727,7 +727,7 @@ static int init(int force, int par1, int par2)
     }
 
     if (__svgalib_driver_report) {
-	fprintf(stderr,"Using I810 driver, %iKB.\n",memory);
+	fprintf(stderr,"Using i810 driver, %iKB.\n",memory);
     };
 
     cardspecs = malloc(sizeof(CardSpecs));
