@@ -628,7 +628,7 @@ static void mil_setregs(const unsigned char regs[], int mode)
 
 static int mil_modeavailable(int mode)
 {
-    struct info *info;
+    struct vgainfo *info;
     ModeTiming *modetiming;
     ModeInfo *modeinfo;
 
