@@ -43,7 +43,7 @@ static void inline _outb(unsigned port,unsigned value)
 #ifdef DEBUG
  fprintf (stderr,"0x%x, 0x%x\n",port,value);
 #endif
-outb(port,value);
+port_out_r(port,value);
 }
 
 /* Fill in chipset specific mode information */
@@ -100,7 +100,7 @@ paradise_unlock();
 b=0;
 for (a=0x03;a<=0x15;)
  { 
- outb(SEQ_I,a);
+ port_out_r(SEQ_I,a);
  regs[EXT+b]=port_in(SEQ_D);
  b++;
  if (a==0x03)a=0x06;
@@ -110,13 +110,13 @@ for (a=0x03;a<=0x15;)
  }
 for (a=0x09;a<=0x0f;a++)
  {
- outb(GRA_I,a);
+ port_out_r(GRA_I,a);
  regs[EXT+b]=port_in(GRA_D);
  b++;
  }  
 for (a=0x29;a<=0x3e;)
  {
- outb(CRT_IC,a);
+ port_out_r(CRT_IC,a);
  regs[EXT+b]=port_in(CRT_DC);
  b++;
  if (a==0x30)a=0x32;
@@ -125,9 +125,9 @@ for (a=0x29;a<=0x3e;)
  else a++;
  }  
 /* VGA registers, not set by shitty svgalib */
-outb(CRT_IC,0x18);
+port_out_r(CRT_IC,0x18);
 regs[EXT+b+1]=port_in(CRT_DC);
-outb(ATT_IW,0x20);
+port_out_r(ATT_IW,0x20);
 __svgalib_delay();
 regs[EXT+b+2]=port_in(ATT_IW);
 return 28;			/* Paradise requires 28 additional registers */
@@ -139,26 +139,26 @@ unsigned char b;
 #ifdef DEBUG
  fprintf(stderr,"paradise_unlock\n");
 #endif
-outw(GRA_I,0x050f);
-outw(CRT_IC,0x8529);
-outw(SEQ_I,0x4806);
+port_outw_r(GRA_I,0x050f);
+port_outw_r(CRT_IC,0x8529);
+port_outw_r(SEQ_I,0x4806);
 /* let's unlock sync, timing ... */
-outb(GRA_I,0xd);
+port_out_r(GRA_I,0xd);
 b=port_in (GRA_D);
 b&=30;
 b|=2;
-outb(GRA_I,0xd);
-outb(GRA_D,b);
-outb(GRA_I,0xe);
+port_out_r(GRA_I,0xd);
+port_out_r(GRA_D,b);
+port_out_r(GRA_I,0xe);
 b=port_in(GRA_D);
 b&=251;
-outb(GRA_I,0xe);
-outb(GRA_D,b);
-outb(CRT_IC,0x2a);
+port_out_r(GRA_I,0xe);
+port_out_r(GRA_D,b);
+port_out_r(CRT_IC,0x2a);
 b=port_in(CRT_DC);
 b&=248;
-outb(CRT_IC,0x2a);
-outb(CRT_DC,b);
+port_out_r(CRT_IC,0x2a);
+port_out_r(CRT_DC,b);
 }
 
 static void paradise_lock(void)
@@ -166,9 +166,9 @@ static void paradise_lock(void)
 #ifdef DEBUG
  fprintf(stderr,"paradise_lock\n");
 #endif
-outw(GRA_I,0x000f);
-outw(CRT_IC,0x0029);
-outw(SEQ_I,0x0006);
+port_outw_r(GRA_I,0x000f);
+port_outw_r(CRT_IC,0x0029);
+port_outw_r(SEQ_I,0x0006);
 }
 
 /* Set chipset-specific registers */
@@ -281,20 +281,20 @@ static int paradise_test(void)
     old_value=port_in(CRT_IC);
     for (a=0;a<5;a++)
      {
-     outb(CRT_IC,0x31+a);
+     port_out_r(CRT_IC,0x31+a);
      txt[a]=port_in(CRT_DC);
      }
     if (strcmp(txt,"WD90C"))
     {
-	outb(CRT_IC,old_value);
+	port_out_r(CRT_IC,old_value);
 	return 0;
     }
     /* check version */
-    outb(CRT_IC, 0x36);
+    port_out_r(CRT_IC, 0x36);
     switch (port_in(CRT_DC))
     {
     case 0x32:  /* WD90C2x */
-    outb(CRT_IC, 0x37);
+    port_out_r(CRT_IC, 0x37);
     switch (port_in(CRT_DC))
      {
      case 0x34:  /* WD90C24 */
@@ -305,8 +305,8 @@ static int paradise_test(void)
      }
     break;
     case 0x33:  /* WD90C3x */
-    outb(CRT_IC, 0x37);
-    outb(CRT_IC, 0x37);
+    port_out_r(CRT_IC, 0x37);
+    port_out_r(CRT_IC, 0x37);
     switch (port_in(CRT_DC))
      {
      case 0x30:  /* WD90C30 */
@@ -335,15 +335,15 @@ static void paradise_setpage(int page)
 #endif
 paradise_unlock();
 /* set read-write paging mode */
-outb(SEQ_I,0x11);
-outb(SEQ_D,port_in(SEQ_D)|0x80);
-outb(GRA_I,0x0b);
-outb(GRA_D,port_in(GRA_D)|0x80);
+port_out_r(SEQ_I,0x11);
+port_out_r(SEQ_D,port_in(SEQ_D)|0x80);
+port_out_r(GRA_I,0x0b);
+port_out_r(GRA_D,port_in(GRA_D)|0x80);
 /* set bank number */
-outb(GRA_I,0x09);
-outb(GRA_D,page<<4);
-outb(GRA_I,0x0a);
-outb(GRA_D,page<<4);
+port_out_r(GRA_I,0x09);
+port_out_r(GRA_D,page<<4);
+port_out_r(GRA_I,0x0a);
+port_out_r(GRA_D,page<<4);
 }
 
 
@@ -355,13 +355,13 @@ static void paradise_setdisplaystart(int address)
  fprintf(stderr,"paradise_setdisplaystart\n");
 #endif
 paradise_unlock();
-outb(CRT_IC,0x2f);
+port_out_r(CRT_IC,0x2f);
 bits=address>>13;
 orig=port_in(CRT_DC);
 orig^=bits;
 orig&=0xe7;
 orig^=bits;
-outb(CRT_DC,orig);
+port_out_r(CRT_DC,orig);
 }
 
 
@@ -373,7 +373,7 @@ static void paradise_setlogicalwidth(int width)
  fprintf(stderr,"paradise_setlogicalwidth\n");
 #endif
 paradise_unlock();
-    outw(CRT_IC, 0x13 + (width >> 3) * 256);
+    port_outw_r(CRT_IC, 0x13 + (width >> 3) * 256);
 }
 
 
@@ -419,7 +419,7 @@ static int paradise_init(int force, int par1, int par2)
 #endif
 	paradise_memory = par1;
     } else {
-	outb(GRA_I,0x0b);
+	port_out_r(GRA_I,0x0b);
 	paradise_memory=(port_in(GRA_D)>>6);
 	switch (paradise_memory)
 	 {
