@@ -449,7 +449,7 @@ static void setregs(const unsigned char regs[], int mode)
 
 static int modeavailable(int mode)
 {
-    struct info *info;
+    struct vgainfo *info;
     ModeTiming *modetiming;
     ModeInfo *modeinfo;
 
@@ -996,9 +996,13 @@ static int test(void)
         case 0x8a21:
         case 0x8a22:
         case 0x8a23:
+        case 0x8a25:
+        case 0x8a26:
         case 0x8c10:
         case 0x8c12:
         case 0x9102:
+		case 0x8d01:
+		case 0x8d02:
 		case 0x8d03:
 		case 0x8d04:
             init(0,0,0);
@@ -1324,6 +1328,8 @@ static int init(int force, int par1, int par2)
         case 0x8c13:
             chipset = SAVAGEMX;
             break;
+        case 0x8a25:
+        case 0x8a26:
 		case 0x8d01:
 		case 0x8d02:
 		case 0x8d03:
