@@ -102,7 +102,7 @@ delete_block(int i)
 	 (mem_info.count - i) * sizeof(struct mem_block));
 	}
 
-void *
+static void *
 LRMI_alloc_real(int size)
 	{
 	int i;
@@ -136,7 +136,7 @@ LRMI_alloc_real(int size)
 	}
 
 
-void
+static void
 LRMI_free_real(void *m)
 	{
 	int i;
@@ -215,7 +215,7 @@ pushw(unsigned short i)
 	}
 
 
-int
+static int
 LRMI_init(void)
 	{
 	void *m;
@@ -294,38 +294,17 @@ LRMI_init(void)
 
 
 static void
-set_regs(struct LRMI_regs *r)
+set_regs(struct vm86_regs *r)
 	{
-	context.vm.regs.edi = r->edi;
-	context.vm.regs.esi = r->esi;
-	context.vm.regs.ebp = r->ebp;
-	context.vm.regs.ebx = r->ebx;
-	context.vm.regs.edx = r->edx;
-	context.vm.regs.ecx = r->ecx;
-	context.vm.regs.eax = r->eax;
+	context.vm.regs = *r;
 	context.vm.regs.eflags = DEFAULT_VM86_FLAGS;
-	context.vm.regs.es = r->es;
-	context.vm.regs.ds = r->ds;
-	context.vm.regs.fs = r->fs;
-	context.vm.regs.gs = r->gs;
 	}
 
 
 static void
-get_regs(struct LRMI_regs *r)
+get_regs(struct vm86_regs *r)
 	{
-	r->edi = context.vm.regs.edi;
-	r->esi = context.vm.regs.esi;
-	r->ebp = context.vm.regs.ebp;
-	r->ebx = context.vm.regs.ebx;
-	r->edx = context.vm.regs.edx;
-	r->ecx = context.vm.regs.ecx;
-	r->eax = context.vm.regs.eax;
-	r->flags = context.vm.regs.eflags;
-	r->es = context.vm.regs.es;
-	r->ds = context.vm.regs.ds;
-	r->fs = context.vm.regs.fs;
-	r->gs = context.vm.regs.gs;
+	*r = context.vm.regs;
 	}
 
 #define DIRECTION_FLAG 	(1 << 10)
@@ -790,19 +769,17 @@ run_vm86(void)
 	}
 
 
-int
-LRMI_call(struct LRMI_regs *r)
+static int
+LRMI_call(struct vm86_regs *r)
 	{
 	unsigned int vret;
 
-	memset(&context.vm.regs, 0, sizeof(context.vm.regs));
-
 	set_regs(r);
 
 	context.vm.regs.cs = r->cs;
-	context.vm.regs.eip = r->ip;
+	context.vm.regs.eip = r->eip & 0xffff;
 
-	if (r->ss == 0 && r->sp == 0)
+	if (r->ss == 0 && (r->esp & 0xffff) == 0)
 		{
 		context.vm.regs.ss = context.stack_seg;
 		context.vm.regs.esp = context.stack_off;
@@ -810,7 +787,7 @@ LRMI_call(struct LRMI_regs *r)
 	else
 		{
 		context.vm.regs.ss = r->ss;
-		context.vm.regs.esp = r->sp;
+		context.vm.regs.esp = r->esp & 0xffff;
 		}
 
 	pushw(context.ret_seg);
@@ -824,8 +801,8 @@ LRMI_call(struct LRMI_regs *r)
 	}
 
 
-int
-LRMI_int(int i, struct LRMI_regs *r)
+static int
+LRMI_int(int i, struct vm86_regs *r)
 	{
 	unsigned int vret;
 	unsigned int seg, off;
@@ -843,14 +820,12 @@ LRMI_int(int i, struct LRMI_regs *r)
 		return 0;
 		}
 
-	memset(&context.vm.regs, 0, sizeof(context.vm.regs));
-
 	set_regs(r);
 
 	context.vm.regs.cs = seg;
 	context.vm.regs.eip = off;
 
-	if (r->ss == 0 && r->sp == 0)
+	if (r->ss == 0 && (r->esp & 0xffff) == 0)
 		{
 		context.vm.regs.ss = context.stack_seg;
 		context.vm.regs.esp = context.stack_off;
@@ -858,7 +833,7 @@ LRMI_int(int i, struct LRMI_regs *r)
 	else
 		{
 		context.vm.regs.ss = r->ss;
-		context.vm.regs.esp = r->sp;
+		context.vm.regs.esp = r->esp & 0xffff;
 		}
 
 	pushw(DEFAULT_VM86_FLAGS);
@@ -872,3 +847,10 @@ LRMI_int(int i, struct LRMI_regs *r)
 	return vret;
 	}
 
+LRMI_callbacks __svgalib_default_LRMI_callbacks = {
+	.rm_init = LRMI_init,
+	.rm_call = LRMI_call,
+	.rm_int = LRMI_int,
+	.rm_alloc_real = LRMI_alloc_real,
+	.rm_free_real = LRMI_free_real,
+};
