@@ -187,7 +187,7 @@ static void IBMRGBSetClock(long freq, int clk, long dacspeed, long fref,
     }
 
 #ifdef DEBUG
-    printf("clk %d, setting to %f, m 0x%02x %d, n 0x%02x %d, df %d\n", clk,
+    fprintf(stderr,"clk %d, setting to %f, m 0x%02x %d, n 0x%02x %d, df %d\n", clk,
 	   ((best_m + 65.0) / best_n) / (8 >> best_df) * ffref,
 	   best_m, best_m, best_n, best_n, best_df);
 #endif
@@ -204,12 +204,12 @@ static void IBMRGB52x_init(void)
 
     idrev = IBMRGB52x_probe();
     if (__svgalib_driver_report)
-	printf("svgalib: Using IBM RGB 52%d PaletteDAC, revision %d.\n",
+	fprintf(stderr,"svgalib: Using IBM RGB 52%d PaletteDAC, revision %d.\n",
 	       (idrev >> 8) == 1 ? 5 : 4,
 	       idrev & 0xff);
 #else
     if (__svgalib_driver_report)
-	printf("svgalib: Using IBM RGB 52x PaletteDAC.\n");
+	fprintf(stderr,"svgalib: Using IBM RGB 52x PaletteDAC.\n");
 #endif
     /* set RS2 */
     port_out(0x55, 0x3D4);
@@ -241,7 +241,7 @@ static void IBMRGB52x_initialize_clock_state(unsigned char *regs, int freq)
 		   IBMRGB52x_fref, &m, &n, &df);
 
     if (__svgalib_driver_report)
-	printf("clk %d, setting to %.3f, m 0x%02x %d, n 0x%02x %d, df %d\n",
+	fprintf(stderr,"clk %d, setting to %.3f, m 0x%02x %d, n 0x%02x %d, df %d\n",
 	       IBMRGB52x_clk, ((m + 65.0) / n) / (8 >> df) * IBMRGB52x_fref / 1000,
 	       m, m, n, n, df);
 
